@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-' a module for calculating the Similarity/Correlation Cosfficient between two different modes data '
+' a module for calculating the Similarity/Correlation Coefficient between two different modes data '
 
 __author__ = 'Zitong Lu'
 
@@ -49,7 +49,7 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, chl_opt=0, time_opt=0, time_wi
         Calculate the RDM & similarities for each time-point or not
         If time_opt=0, calculating based on whole time-points' data.
         If time_opt=1, calculating based on each time-points respectively.
-    time_win : Default is 5.
+    time_win : int. Default is 5.
         Set a time-window for calculating the RDM & similarities for different time-points.
         Only when time_opt=1, time_win works.
         If time_win=5, that means each calculation process based on 5 time-points.
@@ -62,13 +62,14 @@ def bhvANDeeg_corr(bhv_data, eeg_data, sub_opt=0, chl_opt=0, time_opt=0, time_wi
         Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
         Cosine Similarities. If method='distance', calculate the Euclidean Distances.
     rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the
+        values on the diagonal.
 
     Returns
     -------
     corrs : array
-        The similarities between behavioral data and EEG/MEG/fNIRS data
+        The similarities between behavioral data and EEG/MEG/fNIRS data.
         If sub_opt=0 & chl_opt=0 & time_opt=0, return one corr result.
             The shape of corrs is [2], a r-value and a p-value. If method='similarity' or method='distance', the
             p-value is 0.
@@ -330,7 +331,7 @@ def bhvANDecog_corr(bhv_data, ele_data, time_win=5, time_step=5, ecog_opt="allin
     Parameters
     ----------
     bhv_data : array
-
+        The behavioral data.
         The shape of bhv_data must be [n_cons, n_trials].
         n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
         respectively.
@@ -339,7 +340,7 @@ def bhvANDecog_corr(bhv_data, ele_data, time_win=5, time_step=5, ecog_opt="allin
         The shape of EEGdata must be [n_cons, n_trials, n_chls, n_ts].
         n_cons, n_trials, n_chls & n_ts represent the number of conidtions, the number of trials,
         the number of channels & the number of time-points, respectively.
-    time_win : Default is 5.
+    time_win : int. Default is 5.
         Set a time-window for calculating the RDM & similarities for different time-points.
         Only when time_opt=1, time_win works.
         If time_win=5, that means each calculation process based on 5 time-points.
@@ -350,15 +351,16 @@ def bhvANDecog_corr(bhv_data, ele_data, time_win=5, time_step=5, ecog_opt="allin
         Calculate the RDM for each channel or for each time-point or for the whole data.
         If ecog_opt='channel', return n_chls RDMs based on each channel's data.
         If ecog_opt='time', return int((n_ts-time_win)/time_step)+1 RDMs based on each time-point's data respectively.
-        If ecog_opt='allin', return only one RDM based on all data
+        If ecog_opt='allin', return only one RDM based on all data.
     method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
         The method to calculate the similarities.
         If method='spearman', calculate the Spearman Correlations. If method='pearson', calculate the Pearson
         Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
         Cosine Similarities. If method='distance', calculate the Euclidean Distances.
     rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the
+        values on the diagonal.
 
     Returns
     -------
@@ -469,7 +471,7 @@ def bhvANDecog_corr(bhv_data, ele_data, time_win=5, time_step=5, ecog_opt="allin
     return corr
 
 
-' a function for calculating the Similarity/Correlation Cosfficient between behavioral data and fMRI data for searchlight'
+' a function for calculating the Similarity/Correlation Cosfficient between behavioral data and fMRI data (searchlight) '
 
 def bhvANDfmri_corr(bhv_data, fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], method="spearman", rescale=False):
 
@@ -479,16 +481,16 @@ def bhvANDfmri_corr(bhv_data, fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], met
     Parameters
     ----------
     bhv_data : array
+        The behavioral data.
         The shape of bhv_data must be [n_cons, n_subs, n_trials].
         n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
         respectively.
     fmri_data : array
         The fmri data.
-        The shape of fmri_data must be [n_cons, n_subs, n_chls, nx, ny, nz].
-        n_cons, n_chls, nx, ny, nz represent the number of conidtions, the number of channels &
-        the size of fMRI-img, respectively.
+        The shape of fmri_data must be [n_cons, n_subs, nx, ny, nz]. n_cons, nx, ny, nz represent the number of
+        conditions, the number of subs & the size of fMRI-img, respectively.
     ksize : array or list [kx, ky, kz]. Default is [3, 3, 3].
-        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis
+        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis.
     strides : array or list [sx, sy, sz]. Default is [1, 1, 1].
         The strides for calculating along the x, y, z axis.
     method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
@@ -497,8 +499,9 @@ def bhvANDfmri_corr(bhv_data, fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], met
         Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
         Cosine Similarities. If method='distance', calculate the Euclidean Distances.
     rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the
+        values on the diagonal.
 
     Returns
     -------
@@ -566,7 +569,7 @@ def bhvANDfmri_corr(bhv_data, fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], met
     return corrs
 
 
-' a function for calculating the Similarity/Correlation Cosfficient between behavioral EEG/MEG/fNIRS and fMRI data for searchlight'
+' a function for calculating the Similarity/Correlation Cosfficient between behavioral EEG/MEG/fNIRS and fMRI data (searchlight) '
 
 def eegANDfmri_corr(eeg_data, fmri_data, chl_opt=0, ksize=[3, 3, 3], strides=[1, 1, 1], method="spearman", rescale=False):
 
@@ -582,15 +585,14 @@ def eegANDfmri_corr(eeg_data, fmri_data, chl_opt=0, ksize=[3, 3, 3], strides=[1,
         of trials, the number of channels & the number of time-points, respectively.
     fmri_data : array
         The fmri data.
-        The shape of fmri_data must be [n_cons, n_subs, n_chls, nx, ny, nz].
-        n_cons, n_chls, nx, ny, nz represent the number of conidtions, the number of channels &
-        the size of fMRI-img, respectively.
+        The shape of fmri_data must be [n_cons, n_subs, nx, ny, nz]. n_cons, nx, ny, nz represent the number of
+        conditions, the number of subs & the size of fMRI-img, respectively.
     chl_opt : int 0 or 1. Default is 0.
         Calculate the RDM & similarities for each channel or not.
         If chl_opt=0, calculating based on all channels' data.
         If chl_opt=1, calculating based on each channel's data respectively.
     ksize : array or list [kx, ky, kz]. Default is [3, 3, 3].
-        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis
+        The size of the fMRI-img. nx, ny, nz represent the number of voxels along the x, y, z axis.
     strides : array or list [sx, sy, sz]. Default is [1, 1, 1].
         The strides for calculating along the x, y, z axis.
     method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
@@ -599,8 +601,8 @@ def eegANDfmri_corr(eeg_data, fmri_data, chl_opt=0, ksize=[3, 3, 3], strides=[1,
         Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
         Cosine Similarities. If method='distance', calculate the Euclidean Distances.
     rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
