@@ -15,19 +15,19 @@ from neurora.rdm_corr import rdm_distance
 np.seterr(divide='ignore', invalid='ignore')
 
 
-' a function for calculating the Similarity/Correlation Cosfficient between RDMs based on EEG/MEG/fNIRS/ECoG/electrophysiological RDMs and a demo RDM'
+' a function for calculating the Similarity/Correlation Cosfficient between RDMs based on EEG/MEG/fNIRS/ECoG/sEEG/electrophysiological RDMs and a demo RDM'
 
 def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
 
     """
-    Calculate the Similarities between EEG/MEG/fNIRS/ECoG/electrophysiological RDMs and a demo RDM
+    Calculate the Similarities between EEG/MEG/fNIRS/ECoG/sEEG/electrophysiological RDMs and a demo RDM
 
     Parameters
     ----------
     demo_rdm : array [n_cons, n_cons]
         A demo RDM.
     eeg_rdms : array
-        The EEG/MEG/fNIRS/ECoG/electrophysiological RDM(s).
+        The EEG/MEG/fNIRS/ECoG/sEEG/electrophysiological RDM(s).
         The shape can be [n_cons, n_cons] or [n1, n_cons, n_cons] or [n1, n2, n_cons, n_cons] or
         [n1, n2, n3, n_cons, n_cons]. ni(i=1, 2, 3) can be int(n_ts/timw_win), n_chls, n_subs.
     method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
@@ -36,13 +36,13 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
         Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
         Cosine Similarities. If method='distance', calculate the Euclidean Distances.
     rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
     corrs : array
-        The similarities between EEG/MEG/fNIRS/ECoG/electrophysiological RDM and a demo RDM
+        The similarities between EEG/MEG/fNIRS/ECoG/sEEG/electrophysiological RDMs and a demo RDM
         If the shape of eeg_rdms is [n_cons, n_cons], the shape of corrs will be [2]. If the shape of eeg_rdms is
         [n1, n_cons, n_cons], the shape of corrs will be [n1, 2]. If the shape of eeg_rdms is [n1, n2, n_cons, n_cons],
         the shape of corrs will be [n1, n2, 2]. If the shape of eeg_rdms is [n1, n2, n3, n_cons, n_cons], the shape of
@@ -139,20 +139,20 @@ def rdms_corr(demo_rdm, eeg_rdms, method="spearman", rescale=False):
     return corr
 
 
-' a function for calculating the Similarity/Correlation Cosfficient between RDMs based on fMRI RDMs and a demo RDM'
+' a function for calculating the Similarity/Correlation Cosfficient between fMRI RDMs and a demo RDM'
 
 def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False):
 
 
     """
-    Calculate the Similarities between fMRI  searchlight RDMs and a demo RDM
+    Calculate the Similarities between fMRI searchlight RDMs and a demo RDM
 
     Parameters
     ----------
     demo_rdm : array [n_cons, n_cons]
         A demo RDM.
     fmri_rdms : array
-        The fMRI-Searchlight RDM.
+        The fMRI-Searchlight RDMs.
         The shape of RDMs is [n_x, n_y, n_z, n_cons, n_cons]. n_x, n_y, n_z represent the number of calculation units
         for searchlight along the x, y, z axis.
     method : string 'spearman' or 'pearson' or 'kendall' or 'similarity' or 'distance'. Default is 'spearman'.
@@ -161,8 +161,8 @@ def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False):
         Correlations. If methd='kendall', calculate the Kendall tau Correlations. If method='similarity', calculate the
         Cosine Similarities. If method='distance', calculate the Euclidean Distances.
     rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
@@ -171,7 +171,6 @@ def fmrirdms_corr(demo_rdm, fmri_rdms, method="spearman", rescale=False):
         The shape of RDMs is [n_x, n_y, n_z, 2]. n_x, n_y, n_z represent the number of calculation units for searchlight
         along the x, y, z axis and 2 represents a r-value and a p-value.
     """
-
     # calculate the number of the calculation units in the x, y, z directions
     n_x = np.shape(fmri_rdms)[0]
     n_y = np.shape(fmri_rdms)[1]
