@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-' a module for calculating the correlation coefficient between two RDMs '
+' a module for calculating the Similarity/Correlation Coefficient between two RDMs '
 
 __author__ = 'Zitong Lu'
 
@@ -21,15 +21,15 @@ def rdm_correlation_spearman(RDM1, RDM2, rescale=False):
     ----------
     RDM1 : array [ncons, ncons]
         The RDM 1.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM1 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
     RDM2 : array [ncons, ncons].
         The RDM 2.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM2 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+    rescale : bool True or False. Default is False.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
@@ -122,15 +122,15 @@ def rdm_correlation_pearson(RDM1, RDM2, rescale=False):
     ----------
     RDM1 : array [ncons, ncons]
         The RDM 1.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM1 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
     RDM2 : array [ncons, ncons].
         The RDM 2.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM2 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+    rescale : bool True or False. Default is False.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
@@ -215,15 +215,15 @@ def rdm_correlation_kendall(RDM1, RDM2, rescale=False):
     ----------
     RDM1 : array [ncons, ncons]
         The RDM 1.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM1 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
     RDM2 : array [ncons, ncons].
         The RDM 2.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM2 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+    rescale : bool True or False. Default is False.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
@@ -309,20 +309,21 @@ def rdm_similarity(RDM1, RDM2, rescale=False):
     ----------
     RDM1 : array [ncons, ncons]
         The RDM 1.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM1 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
     RDM2 : array [ncons, ncons].
         The RDM 2.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM2 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+    rescale : bool True or False. Default is False.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
-    corr : float
+    corr : array [r, p].
         The Cosine Similarity result.
+        The shape of corr is [2], corr[0] is the Cosine Similarity result and corr[1] is 0.
     """
 
     # get number of conditions
@@ -409,20 +410,21 @@ def rdm_distance(RDM1, RDM2, rescale=False):
     ----------
     RDM1 : array [ncons, ncons]
         The RDM 1.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM1 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
     RDM2 : array [ncons, ncons].
         The RDM 2.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM2 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
-    rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+    rescale : bool True or False. Default is False.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
-    corr : float
+    corr : array [r, p].
         The Euclidean Distance result.
+        The shape of corr is [2], corr[0] is the Euclidean Distance result and corr[1] is 0.
     """
 
     # get number of conditions
@@ -504,17 +506,17 @@ def rdm_permutation(RDM1, RDM2, iter=1000, rescale=False):
     ----------
     RDM1 : array [ncons, ncons]
         The RDM 1.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM1 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
     RDM2 : array [ncons, ncons].
         The RDM 2.
-        The shape of fmri_data must be [n_cons, n_cons].
+        The shape of RDM2 must be [n_cons, n_cons].
         n_cons represent the number of conidtions.
     iter : int. Default is 1000.
         The times for iteration.
-    rescale : bool True or False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
-        values on the diagnal.
+    rescale : bool True or False. Default is False.
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the values on the diagonal.
 
     Returns
     -------
