@@ -25,7 +25,8 @@ def plot_rdm(rdm, rescale=False, conditions=None, con_fontsize=12, cmap=None):
     rdm : array or list [n_cons, n_cons]
         A representational dissimilarity matrix.
     rescale : bool True or False. Default is False.
-        Rescale the values in RDM or not. Here, the maximum-minimum method is used to rescale the values except for the
+        Rescale the values in RDM or not.
+        Here, the maximum-minimum method is used to rescale the values except for the
         values on the diagnal.
     conditions : string-array or string-list. Default is None.
         The labels of the conditions for plotting.
@@ -289,7 +290,7 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
         time_unit=[0, 0.1], which means the start time of corrs is 0 sec and the time step is 0.1 sec.
     lim : array or list [min, max].
         The corrs view lims.
-    smooth : boolean True or False
+    smooth : bool True or False
         Smooth the results or not.
     figsize : array or list, [size_X, size_Y]
         The size of the figure.
@@ -436,7 +437,7 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
         If figsize=None, the size of the figure will be ajusted automatically.
     cmap : matplotlib colormap or None. Default is None.
         The colormap for the figure.
-        If cmap=None, the ccolormap will be 'inferno'.
+        If cmap=None, the ccolormap will be 'viridis'.
     """
 
     # absolute value
@@ -555,7 +556,7 @@ def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2()):
         The threshold of the number of voxels used in correction.
         If threshold=n, only the similarity clusters consisting more than threshold voxels will be visible. If it is
         None, the threshold-correction will not work.
-    background : Niimg-like object or string. Default is neurora.stuff.get_bg_ch2()
+    background : Niimg-like object or string. Default is stuff.get_bg_ch2()
         The background image that the RSA results will be plotted on top of.
     """
 
@@ -601,7 +602,7 @@ def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_b
         y, z direction. If slice=[[slice_x1, slice_x2], [slice_y1, slice_y2], [slice_z1, slice_z2]], slice_x1 & slice_x2
         represent the coordinates of each cut in the x direction, slice_y1 & slice_y2 represent the coordinates of each
         cut in the y direction, slice_z1 & slice_z2 represent the coordinates of each cut in the z direction.
-    background : Niimg-like object or string. Default is neurora.stuff.get_bg_ch2bet()
+    background : Niimg-like object or string. Default is stuff.get_bg_ch2bet()
         The background image that the RSA results will be plotted on top of.
     """
 
@@ -730,7 +731,7 @@ def plot_brainrsa_surface(img, threshold=None):
 def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None):
 
     """
-    Plot the RSA-result into a brain surface
+    Plot the RSA-result by a set of images
 
     Parameters
     ----------
@@ -740,6 +741,8 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None):
         The threshold of the number of voxels used in correction.
         If threshold=n, only the similarity clusters consisting more than threshold voxels will be visible. If it is
         None, the threshold-correction will not work.
+    background : Niimg-like object or string. Default is None.
+        The background image that the RSA results will be plotted on top of.
     """
 
     imgarray = nib.load(img).get_data()
