@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-' a module for plotting the NeuroRA results '
+' a module for calculating the spatiotemporal pattern similarity based on neural data '
 
 __author__ = 'Zitong Lu'
 
@@ -31,9 +31,9 @@ def stps(data1, data2, time_win=20, time_step=1):
         The shape of data1 must be [n_subs2, n_chls, n_trials2, n_ts]. n_subs2, n_chls, n_trials2, n_ts represent the
         number of subjects, the number of channels or regions, the number of trials and the number of time-points of the
         data under condition 2.
-    time_win : int. Default is 5.
+    time_win : int. Default is 20.
         Set a time-window for calculating the STPS for different time-points.
-        If time_win=5, that means each calculation process based on 5 time-points.
+        If time_win=20, that means each calculation process based on 20 time-points.
     time_step : int. Default is 5.
         The time step size for each time of calculating.
 
